package com.muyu.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.domain.TaskInfo;
import com.muyu.domain.req.TaskInfoReq;
import com.muyu.service.TaskService;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static com.muyu.common.core.utils.PageUtils.startPage;

/**
 * @PackageName:com.muyu.controller
 * @ClassName:TaskController
 * @Description:
 * @author: ￥陈思豪￥
 * @date: 2024/8/22 17:09
 */
@RestController
@RequestMapping("/task")
public class TaskController {

    @Autowired
    private TaskService taskService;

    @RequestMapping(path = "/list", method = RequestMethod.POST)
    @Operation(summary = "查看指定任务", description = "根据任务的名称或者状态 ，进行模糊查询")
    public Result<List<TaskInfo>> selectList(
            @Validated @RequestBody TaskInfoReq taskInfoReq) {
        startPage();
        return Result.success(
                taskService.selectList(taskInfoReq)
        );
    }


    /**
     * 添加新任务
     */
    @RequestMapping(path = "/addTask", method = RequestMethod.POST)
    @Operation(summary = "添加任务", description = "根据传来的数据进行任务添加")
    public Result<String> addTask(
            @Validated @RequestBody TaskInfo taskInfo) {

        return Result.success(null,taskService.addTask(taskInfo));
    }

    /**
     * 修改任务信息
     */
    @RequestMapping(path = "/updateById", method = RequestMethod.POST)
    @Operation(summary = "对指定任务进行修改", description = "根据传来的数据进行相应的修改")
    public Result<String> updateById(
            @Validated @RequestBody TaskInfo taskInfo) {
        return Result.success(
                taskService.updById(taskInfo),"修改成功"
        );
    }

    /**
     * 删除任务
     */
    @RequestMapping(path = "/deleteById/{id}", method = RequestMethod.POST)
    @Operation(summary = "对指定任务进行删除", description = "根据传来的id进行删除")
    public Result<String> deleteById(@PathVariable(name = "id") Integer id) {
        return Result.success(
                taskService.deleteById(id), "删除成功"
        );
    }

    /**
     * 执行任务
     */
    @RequestMapping(path = "/executeTask/{taskId}", method = RequestMethod.POST)
    @Operation(summary = "对指定任务进行执行", description = "根据传来的id进行执行")
    public Result<String> executeTask(@PathVariable(name = "taskId") Integer taskId) {
        return Result.success(
                taskService.executeTask(taskId), "执行成功"
        );
    }


}
